import React, { useEffect, useState } from 'react';
import {
  StyleSheet,
  View,
  Text,
  FlatList,
  TouchableOpacity,
  Image,
  ActivityIndicator,
  RefreshControl,
  ScrollView,
} from 'react-native';
import { SafeAreaView } from 'react-native-safe-area-context';
import { getRecentContent, getCategories } from '../services/api';
import ContentCard from '../components/ContentCard';
import CategoryPill from '../components/CategoryPill';

const HomeScreen = ({ navigation }: any) => {
  const [recentContent, setRecentContent] = useState([]);
  const [categories, setCategories] = useState([]);
  const [loading, setLoading] = useState(true);
  const [refreshing, setRefreshing] = useState(false);

  const fetchData = async () => {
    try {
      setLoading(true);
      const [contentData, categoriesData] = await Promise.all([
        getRecentContent(10),
        getCategories(),
      ]);
      setRecentContent(contentData);
      setCategories(categoriesData);
    } catch (error) {
      console.error('Error fetching home data:', error);
    } finally {
      setLoading(false);
    }
  };

  const handleRefresh = async () => {
    setRefreshing(true);
    await fetchData();
    setRefreshing(false);
  };

  useEffect(() => {
    fetchData();
  }, []);

  const navigateToContent = (item: any) => {
    if (item.type === 'movie') {
      navigation.navigate('VideoPlayer', { videoId: item.id, videoType: 'movie', title: item.title });
    } else if (item.type === 'series') {
      navigation.navigate('Series', { seriesId: item.id });
    } else if (item.type === 'channel') {
      navigation.navigate('VideoPlayer', { videoId: item.id, videoType: 'channel', title: item.name });
    } else if (item.type === 'match') {
      navigation.navigate('VideoPlayer', { videoId: item.id, videoType: 'match', title: item.title });
    }
  };

  const navigateToCategory = (category: any) => {
    if (category.name === 'أفلام') {
      navigation.navigate('Movies');
    } else if (category.name === 'مسلسلات') {
      navigation.navigate('Series');
    } else if (category.name === 'قنوات') {
      navigation.navigate('Channels');
    } else if (category.name === 'مباريات') {
      navigation.navigate('Matches');
    }
  };

  if (loading) {
    return (
      <View style={styles.loadingContainer}>
        <ActivityIndicator size="large" color="#E50914" />
        <Text style={styles.loadingText}>جاري تحميل المحتوى...</Text>
      </View>
    );
  }

  return (
    <SafeAreaView style={styles.container}>
      <ScrollView
        refreshControl={
          <RefreshControl refreshing={refreshing} onRefresh={handleRefresh} />
        }
      >
        <View style={styles.header}>
          <Text style={styles.headerTitle}>Saqr TV</Text>
        </View>

        <View style={styles.categoriesContainer}>
          <FlatList
            data={categories}
            horizontal
            showsHorizontalScrollIndicator={false}
            keyExtractor={(item) => item.id.toString()}
            renderItem={({ item }) => (
              <CategoryPill
                category={item}
                onPress={() => navigateToCategory(item)}
              />
            )}
            contentContainerStyle={styles.categoriesList}
          />
        </View>

        <View style={styles.sectionContainer}>
          <Text style={styles.sectionTitle}>أحدث المحتوى</Text>
          <View style={styles.contentGrid}>
            {recentContent.map((item) => (
              <ContentCard
                key={`${item.type}-${item.id}`}
                item={item}
                onPress={() => navigateToContent(item)}
              />
            ))}
          </View>
        </View>
      </ScrollView>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#121212',
  },
  loadingContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#121212',
  },
  loadingText: {
    color: '#fff',
    marginTop: 10,
  },
  header: {
    padding: 15,
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
  },
  headerTitle: {
    fontSize: 22,
    color: '#E50914',
    fontWeight: 'bold',
  },
  categoriesContainer: {
    marginVertical: 10,
  },
  categoriesList: {
    paddingHorizontal: 15,
  },
  sectionContainer: {
    marginVertical: 15,
    paddingHorizontal: 15,
  },
  sectionTitle: {
    fontSize: 18,
    color: '#fff',
    fontWeight: 'bold',
    marginBottom: 15,
    textAlign: 'right',
  },
  contentGrid: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    justifyContent: 'space-between',
  },
});

export default HomeScreen;