import React, { useEffect, useState } from 'react';
import {
  StyleSheet,
  View,
  Text,
  FlatList,
  ActivityIndicator,
  RefreshControl,
} from 'react-native';
import { SafeAreaView } from 'react-native-safe-area-context';
import { getAllSeries, getEpisodes } from '../services/api';
import ContentCard from '../components/ContentCard';

const SeriesScreen = ({ route, navigation }: any) => {
  const [series, setSeries] = useState([]);
  const [loading, setLoading] = useState(true);
  const [refreshing, setRefreshing] = useState(false);

  const fetchSeries = async () => {
    try {
      setLoading(true);
      const seriesData = await getAllSeries();
      // Add type property for ContentCard component
      const seriesWithType = seriesData.map((item: any) => ({
        ...item,
        type: 'series',
      }));
      setSeries(seriesWithType);
    } catch (error) {
      console.error('Error fetching series:', error);
    } finally {
      setLoading(false);
    }
  };

  const handleRefresh = async () => {
    setRefreshing(true);
    await fetchSeries();
    setRefreshing(false);
  };

  useEffect(() => {
    fetchSeries();
  }, []);

  const handleSeriesPress = async (item: any) => {
    try {
      const episodes = await getEpisodes(item.id);
      if (episodes && episodes.length > 0) {
        // If there are episodes, navigate to a screen that lists them
        // For now, just play the first episode
        navigation.navigate('VideoPlayer', {
          videoId: episodes[0].id,
          videoType: 'episode',
          title: `${item.title} - الحلقة ${episodes[0].episodeNumber}`,
        });
      } else {
        // No episodes found
        alert('لا توجد حلقات متاحة لهذا المسلسل');
      }
    } catch (error) {
      console.error('Error fetching episodes:', error);
      alert('حدث خطأ أثناء تحميل الحلقات');
    }
  };

  if (loading && !refreshing) {
    return (
      <View style={styles.loadingContainer}>
        <ActivityIndicator size="large" color="#E50914" />
        <Text style={styles.loadingText}>جاري تحميل المسلسلات...</Text>
      </View>
    );
  }

  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.header}>
        <Text style={styles.headerTitle}>المسلسلات</Text>
      </View>

      {series.length === 0 ? (
        <View style={styles.emptyContainer}>
          <Text style={styles.emptyText}>لا توجد مسلسلات متاحة</Text>
        </View>
      ) : (
        <FlatList
          data={series}
          numColumns={2}
          refreshControl={
            <RefreshControl refreshing={refreshing} onRefresh={handleRefresh} />
          }
          keyExtractor={(item) => item.id.toString()}
          renderItem={({ item }) => (
            <ContentCard item={item} onPress={() => handleSeriesPress(item)} />
          )}
          contentContainerStyle={styles.seriesList}
        />
      )}
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#121212',
  },
  loadingContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#121212',
  },
  loadingText: {
    color: '#fff',
    marginTop: 10,
  },
  header: {
    padding: 15,
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
  },
  headerTitle: {
    fontSize: 22,
    color: '#fff',
    fontWeight: 'bold',
  },
  seriesList: {
    paddingHorizontal: 15,
    paddingBottom: 20,
  },
  emptyContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  emptyText: {
    color: '#fff',
    fontSize: 16,
  },
});

export default SeriesScreen;